<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Mwb_Role_Based_Pricing_For_Woocommerce
 * @subpackage Mwb_Role_Based_Pricing_For_Woocommerce/admin/partials
 */

if ( ! defined( 'ABSPATH' ) ) {

	exit(); // Exit if accessed directly.
}
$roles_obj         = new WP_Roles();
$roles_names_array = $roles_obj->get_names();
$guest             = array( 'guest' => 'Guest' );
$roles_names_array = array_merge( $guest, $roles_names_array );
if ( isset( $_POST['save_user_setting'] ) && isset( $_POST['user-setting-nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['user-setting-nonce'] ) ), 'user-setting-nonce' ) ) {
	foreach ( $roles_names_array as $key => $role_name ) {
		$role_name = sanitize_text_field( wp_unslash( $role_name ) );
		$role_name = str_replace( ' ', '_', strtolower( $role_name ) );
		if ( isset( $_POST ) && ! array_key_exists( 'user_setting_' . $role_name, $_POST ) ) {
			update_option( 'user_setting_' . $role_name, '' );
		}
	}
	if ( ! empty( $_POST ) ) {
		foreach ( map_deep( wp_unslash( $_POST ), 'sanitize_text_field' ) as $key => $value ) {
			if ( 'save_user_setting' === $key ) {
				break;
			}
			update_option( $key, $value );
		}
	}
	do_action( 'mwb_mrbpfw_user_setting_save' );
	?>
	<?php
}
global $mrbpfw_mwb_mrbpfw_obj;
$mrbpfw_active_tab   = isset( $_GET['mrbpfw_tab'] ) ? sanitize_key( $_GET['mrbpfw_tab'] ) : 'mwb-role-based-pricing-for-woocommerce-general';
$mrbpfw_default_tabs = $mrbpfw_mwb_mrbpfw_obj->mwb_mrbpfw_plug_default_tabs();
?>
<header>
	<div class="mwb-header-container mwb-bg-white mwb-r-8">
		<h1 class="mwb-header-title"><?php esc_html_e( 'MWB ROLE BASED PRICING FOR WOOCOMMERCE', 'mwb-role-based-pricing-for-woocommerce' ); ?></h1>
		<a href="https://docs.makewebbetter.com/mwb-role-based-pricing-for-woocommerce/?utm_source=MWB-rolebased-org&utm_medium=MWB-org-page&utm_campaign=MWB-rolebased-org"" target="_blank" class="mwb-link"><?php esc_html_e( 'Documentation', 'mwb-role-based-pricing-for-woocommerce' ); ?></a>
		<span>|</span>
		<a href="https://makewebbetter.com/submit-query/?utm_source=MWB-rolebased-org&utm_medium=MWB-org-page&utm_campaign=MWB-rolebased-org" target="_blank" class="mwb-link"><?php esc_html_e( 'Support', 'mwb-role-based-pricing-for-woocommerce' ); ?></a>
	</div>
</header>

<main class="mwb-main mwb-bg-white mwb-r-8">
	<nav class="mwb-navbar">
		<ul class="mwb-navbar__items">
			<?php
			if ( is_array( $mrbpfw_default_tabs ) && ! empty( $mrbpfw_default_tabs ) ) {

				foreach ( $mrbpfw_default_tabs as $mrbpfw_tab_key => $mrbpfw_default_tabs ) {

					$mrbpfw_tab_classes = 'mwb-link ';

					if ( ! empty( $mrbpfw_active_tab ) && $mrbpfw_active_tab === $mrbpfw_tab_key ) {
						$mrbpfw_tab_classes .= 'active';
					}
					?>
					<li>
						<a id="<?php echo esc_attr( $mrbpfw_tab_key ); ?>" href="<?php echo esc_url( admin_url( 'admin.php?page=mwb_role_based_pricing_for_woocommerce_menu' ) . '&mrbpfw_tab=' . esc_attr( $mrbpfw_tab_key ) ); ?>" class="<?php echo esc_attr( $mrbpfw_tab_classes ); ?>"><?php echo esc_html( $mrbpfw_default_tabs['title'] ); ?></a>
					</li>
					<?php
				}
			}
			?>
		</ul>
	</nav>

	<section class="mwb-section">
		<div>
			<?php
				do_action( 'mwb_mrbpfw_before_general_settings_form' );
						// if submenu is directly clicked on woocommerce.
			if ( empty( $mrbpfw_active_tab ) ) {
				$mrbpfw_active_tab = 'mwb_mrbpfw_plug_general';
			}

						// look for the path based on the tab id in the admin templates.
				$mrbpfw_tab_content_path = 'admin/partials/' . $mrbpfw_active_tab . '.php';

				$mrbpfw_mwb_mrbpfw_obj->mwb_mrbpfw_plug_load_template( $mrbpfw_tab_content_path );

				do_action( 'mwb_mrbpfw_after_general_settings_form' );
			?>
		</div>
	</section>
